Index: libvirt.c
===================================================================
RCS file: /data/cvs/libvirt/src/libvirt.c,v
retrieving revision 1.68
diff -u -p -r1.68 libvirt.c
--- libvirt.c	18 Apr 2007 10:14:07 -0000	1.68
+++ libvirt.c	27 Apr 2007 08:05:35 -0000
@@ -1261,6 +1261,42 @@ virDomainSetMaxMemory(virDomainPtr domai
     return -1;
 }
 
+int
+virDomainSetMaxMemoryScope(virDomainPtr domain, unsigned long memory, int scope)
+{
+    virConnectPtr conn;
+
+    if (domain == NULL) {
+        TODO
+        return (-1);
+    }
+    if (!VIR_IS_CONNECTED_DOMAIN(domain)) {
+        virLibDomainError(domain, VIR_ERR_INVALID_DOMAIN, __FUNCTION__);
+        return (-1);
+    }
+    if (domain->conn->flags & VIR_CONNECT_RO) {
+        virLibDomainError(domain, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
+        return (-1);
+    }
+    if (memory < 4096) {
+        virLibDomainError(domain, VIR_ERR_INVALID_ARG, __FUNCTION__);
+        return (-1);
+    }
+    conn = domain->conn;
+
+    if (scope == VIR_DOMAIN_SCOPE_CURRENT){
+        if (conn->driver->domainSetMaxMemory)
+            return conn->driver->domainSetMaxMemory (domain, memory);
+    } else {
+        /* TODO */
+        if (conn->driver->domainSetMaxMemory)
+            return conn->driver->domainSetMaxMemoryScope (domain, memory, scope);
+    }
+
+    virLibConnError (conn, VIR_ERR_CALL_FAILED, __FUNCTION__);
+    return -1;
+}
+
 /**
  * virDomainSetMemory:
  * @domain: a domain object or NULL
@@ -1304,6 +1340,47 @@ virDomainSetMemory(virDomainPtr domain, 
     return -1;
 }
 
+int
+virDomainSetMemoryScope(virDomainPtr domain, unsigned long memory, int scope)
+{
+    virConnectPtr conn;
+    virDomainPtr dom;
+    int ret_op=0, ret_static=0, ret_dynamic=0, ret_define=0;
+    char *dump=NULL, *out=NULL;
+    char value[20];
+
+    if (domain == NULL) {
+        TODO
+        return (-1);
+    }
+    if (!VIR_IS_CONNECTED_DOMAIN(domain)) {
+        virLibDomainError(domain, VIR_ERR_INVALID_DOMAIN, __FUNCTION__);
+        return (-1);
+    }
+    if (domain->conn->flags & VIR_CONNECT_RO) {
+        virLibDomainError(domain, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
+        return (-1);
+    }
+    if (memory < 4096) {
+        virLibDomainError(domain, VIR_ERR_INVALID_ARG, __FUNCTION__);
+        return (-1);
+    }
+
+    conn = domain->conn;
+
+    if (scope == VIR_DOMAIN_SCOPE_CURRENT){
+        if (conn->driver->domainSetMemory)
+            return conn->driver->domainSetMemory (domain, memory);
+    } else {
+        /* TODO */
+        if (conn->driver->domainSetMemory)
+            return conn->driver->domainSetMemoryScope (domain, memory, scope);
+    } 
+
+    virLibConnError (conn, VIR_ERR_CALL_FAILED, __FUNCTION__);
+    return -1;
+}
+
 /**
  * virDomainGetInfo:
  * @domain: a domain object
@@ -1689,6 +1766,42 @@ virDomainSetVcpus(virDomainPtr domain, u
     return -1;
 }
 
+int
+virDomainSetVcpusScope(virDomainPtr domain, unsigned int nvcpus, int scope)
+{
+    virConnectPtr conn;
+
+    if (domain == NULL) {
+        TODO
+        return (-1);
+    }
+    if (!VIR_IS_CONNECTED_DOMAIN(domain)) {
+        virLibDomainError(domain, VIR_ERR_INVALID_DOMAIN, __FUNCTION__);
+        return (-1);
+    }
+    if (domain->conn->flags & VIR_CONNECT_RO) {
+        virLibDomainError(domain, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
+        return (-1);
+    }
+
+    if (nvcpus < 1) {
+        virLibDomainError(domain, VIR_ERR_INVALID_ARG, __FUNCTION__);
+        return (-1);
+    }
+    conn = domain->conn;
+
+    if (scope == VIR_DOMAIN_SCOPE_CURRENT){
+        if (conn->driver->domainSetVcpus)
+            return conn->driver->domainSetVcpus (domain, nvcpus);
+    } else {
+        /* TODO */
+        if (conn->driver->domainSetVcpus)
+            return conn->driver->domainSetVcpusScope (domain, nvcpus, scope);
+    }
+
+    virLibConnError (conn, VIR_ERR_CALL_FAILED, __FUNCTION__);
+    return -1;
+}
 /**
  * virDomainPinVcpu:
  * @domain: pointer to domain object, or NULL for Domain0
